@@ -1197,7 +1197,7 @@ def grid_powerlaw(exp, insert=0, skip=0, end=-1, step=0, axis=None, **kwargs):
     return lines
 
 
-def _fit_powerlaw(
+def _fit_loglog(
     logx: ArrayLike,
     logy: ArrayLike,
     prefactor: float,
@@ -1258,8 +1258,8 @@ def fit_powerlaw(
     :param xdata: Data points along the x-axis.
     :param ydata: Data points along the y-axis.
     :param yerr: Error-bar for ``ydata``.
-    :param prefactor: Prefactor (fitted if not specified).
-    :param exponent: Exponent (fitted if not specified).
+    :param prefactor: Prefactor :math:`c` (fitted if not specified).
+    :param exponent: Exponent :math:`b` (fitted if not specified).
     :param axis: Axis to plot along (not plotted if not specified).
     :param fmt: Format for the label (if plotting). E.g. ``r"${0:.3f} x^{{{1:.2f}}}$"``.
     :param kwargs: Other plot options.
@@ -1269,6 +1269,9 @@ def fit_powerlaw(
         The (fitted) prefector and exponent, and optionally the handle (if plotting)
     """
 
+    xdata = np.array(xdata)
+    ydata = np.array(ydata)
+
     i = np.logical_and(xdata > 0, ydata > 0)
     logx = np.log(xdata[i])
     logy = np.log(ydata[i])
@@ -1285,7 +1288,7 @@ def fit_powerlaw(
         fit_opts["sigma"] = logyerr
         fit_opts["absolute_sigma"] = True
 
-    prefactor, exponent = _fit_powerlaw(logx, logy, prefactor, exponent, **fit_opts)
+    prefactor, exponent = _fit_loglog(logx, logy, prefactor, exponent, **fit_opts)
 
     if axis is None:
         return (prefactor, exponent)
@@ -1329,8 +1332,8 @@ def fit_exp(
     :param xdata: Data points along the x-axis.
     :param ydata: Data points along the y-axis.
     :param yerr: Error-bar for ``ydata``.
-    :param prefactor: Prefactor (fitted if not specified).
-    :param exponent: Exponent (fitted if not specified).
+    :param prefactor: Prefactor :math:`c` (fitted if not specified).
+    :param exponent: Exponent :math:`b` (fitted if not specified).
     :param axis: Axis to plot along (not plotted if not specified).
     :param fmt: Format for the label (if plotting). E.g. ``r"${0:.3f} \exp ({1:.2f} x)$"``.
     :param kwargs: Other plot options.
@@ -1340,6 +1343,9 @@ def fit_exp(
         The (fitted) prefector and exponent, and optionally the handle (if plotting)
     """
 
+    xdata = np.array(xdata)
+    ydata = np.array(ydata)
+
     i = ydata > 0
     x = xdata[i]
     logy = np.log(ydata[i])
@@ -1356,7 +1362,7 @@ def fit_exp(
         fit_opts["sigma"] = logyerr
         fit_opts["absolute_sigma"] = True
 
-    prefactor, exponent = _fit_powerlaw(x, logy, prefactor, exponent, **fit_opts)
+    prefactor, exponent = _fit_loglog(x, logy, prefactor, exponent, **fit_opts)
 
     if axis is None:
         return (prefactor, exponent)
@@ -1377,6 +1383,82 @@ def fit_exp(
     return (prefactor, exponent, h)
 
 
+def fit_linear(
+    xdata: ArrayLike,
+    ydata: ArrayLike,
+    yerr: ArrayLike = None,
+    offset: float = None,
+    slope: float = None,
+    axis: plt.Axes = None,
+    fmt: str = None,
+    **kwargs,
+):
+    r"""
+    Fit a linear function :math:`y = a + b x`.
+
+    :param xdata: Data points along the x-axis.
+    :param ydata: Data points along the y-axis.
+    :param yerr: Error-bar for ``ydata``.
+    :param offset: Offset :math:`a` (fitted if not specified).
+    :param slope: Slope :math:`b` (fitted if not specified).
+    :param axis: Axis to plot along (not plotted if not specified).
+    :param fmt: Format for the label (if plotting). E.g. ``r"${0:.3f} + {1:.2f} x$"``.
+    :param kwargs: Other plot options.
+
+    :return:
+        ``offset, slope[, h]``
+        The (fitted) offset and slope, and optionally the handle (if plotting)
+    """
+
+    xdata = np.array(xdata)
+    ydata = np.array(ydata)
+
+    fit_opts = {}
+
+    if yerr is not None:
+        fit_opts["sigma"] = np.array(yerr)
+        fit_opts["absolute_sigma"] = True
+
+    if offset is None and slope is None:
+
+        def f(x, offset, slope):
+            return offset + slope * x
+
+        param, _ = curve_fit(f, xdata, ydata, **fit_opts)
+        offset = param[0]
+        slope = param[1]
+
+    elif offset is None:
+
+        def f(x, offset):
+            return offset + slope * x
+
+        param, _ = curve_fit(f, xdata, ydata, **fit_opts)
+        offset = param[0]
+
+    elif slope is None:
+
+        def f(x, slope):
+            return offset + slope * x
+
+        param, _ = curve_fit(f, xdata, ydata, **fit_opts)
+        slope = param[0]
+
+    if axis is None:
+        return (offset, slope)
+
+    xp = np.array([np.min(xdata), np.max(xdata)])
+    yp = offset + slope * xp
+
+    if fmt:
+        assert "label" not in kwargs
+        kwargs["label"] = fmt.format(offset, slope)
+
+    h = axis.plot(xp, yp, **kwargs)
+
+    return (offset, slope, h)
+
+
 def random_from_cdf(shape, P, x, linspace=False, shuffle=True):
     r"""
     Generate a random number based on a discrete cumulative probability density function.
@@ -1639,29 +1721,45 @@ def histogram_bin_edges(
     return bin_edges
 
 
+def histogram_norm(count: ArrayLike, bin_edges: ArrayLike, norm: float = 1.0):
+    """
+    Renormalise a histogram.
+
+    :param count: Count.
+    :param bin_edges: Bin-edges.
+    :param norm: Area of the histogram.
+    """
+    assert len(bin_edges) == len(count) + 1
+    return count * norm / np.sum(np.diff(bin_edges) * count)
+
+
+def histogram_bin_edges2midpoint(bin_edges: ArrayLike):
+    """
+    Return the midpoints of every bin-edge.
+
+    :param bin_edges: Bin-edges.
+    :param count: Count per bin.
+    :param norm: Area of the histogram.
+    """
+    return 0.5 * np.diff(bin_edges) + bin_edges[:-1]
+
+
 def histogram(data, return_edges=True, **kwargs):
     r"""
     Compute histogram.
-    See `numpy.histrogram <https://docs.scipy.org/doc/numpy/reference/generated/numpy.histogram.html>`__
+    This function passes all options to
+    `numpy.histrogram <https://docs.scipy.org/doc/numpy/reference/generated/numpy.histogram.html>`__
+    In addition you can use:
 
-    :extra options:
-
-        **return_edges** ([``True``] | [``False``])
-            Return the bin edges if set to ``True``, return their midpoints otherwise.
+    :param return_edges: Return the bin edges if set to ``True``, return their midpoints otherwise.
     """
 
-    # use NumPy's default function to compute the histogram
     P, bin_edges = np.histogram(data, **kwargs)
 
-    # return default output
     if return_edges:
         return P, bin_edges
 
-    # convert bin_edges -> mid-points of each bin
-    x = np.diff(bin_edges) / 2.0 + bin_edges[:-1]
-
-    # return with bin mid-points
-    return P, x
+    return P, histogram_bin_edges2midpoint(bin_edges)
 
 
 def histogram_cumulative(data, **kwargs):
